@@ -1,8 +1,13 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     $no_db=1;
     
     include("../../conf/config.php");
-    
+
+    $db_type="mysql";    
     $dbhost="localhost";
     $db="jffnms";
     $dbuser="root";
@@ -23,7 +28,7 @@
     if ($user) {
     
 	echo "* Creating User $user";
-	$id = user_add($user,1);
+	$id = user_add($user);
 
 	echo ", assigned id: $id, now applying profile.\n";
 	user_modify($id,"","",$user,"Administrator",0);
