@@ -146,7 +146,7 @@ for ($i = 0; $i < $cant; $i++) {
 	$timeout = 101;
 
 	while (($num <= 0) and ($timeout < 100))  {
-	    $num = socket_select($set, NULL, NULL, 0, 1000);
+	    $num = socket_select($set, $dum1=NULL, $dum2=NULL, 0, 1000);
 	    echo $timeout++." - $num\n";
 	}
 
