@@ -1,4 +1,4 @@
-<?
+<?php
 /* Network Autodiscovery. This file is part of JFFNMS
  * Copyright (C) <2004-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -95,10 +95,11 @@
     }
 
     function nmap_pipe ($target, $data) {
+        global $Config;
     
 	if (!is_array($data[$target])) {
     	    $data[$target]["res"] = proc_open(
-		get_config_option("nmap_executable"). " -sP -PB --randomize_hosts -T3 -iL - -oG -",
+		$Config->get("nmap_executable"). " -sP -PB --randomize_hosts -T3 -iL - -oG -",
                 array(0=>array("pipe","r"), 1=>array("pipe","w"), 2=>array("pipe","r")), $data[$target]["pipes"]);
 
 	    fwrite($data[$target]["pipes"][0], $target."\n");
