@@ -15,7 +15,7 @@
 	if ( ($skt = @fsockopen($host_ip, 80, $errno, $errstr, $open_timeout)) == FALSE) {
 	    return $apache_info;
 	}
-	fputs($skt, "GET /server-status?auto HTTP/1.1\r\nHost: ".$hostip."\r\n\r\n");
+	fputs($skt, "GET /server-status?auto HTTP/1.1\r\nHost: ".$host_ip."\r\n\r\n");
 
         $reply = '';
 	while(!feof($skt) && (strlen($reply) < 100)) {
