@@ -22,14 +22,6 @@
 		$clRate  = snmp_walk($ip,$rocommunity,"$linux_tc_oid.1.4");
 		$clCeil  = snmp_walk($ip,$rocommunity,"$linux_tc_oid.1.5");
 
-		/*	
-	    	debug ($ifIndex);
-		debug ($ifNames);
-		debug ($clIndex);
-		debug ($clInt);
-		debug ($clNames);
-		*/
-
 		if (is_array($ifIndex) && is_array($ifNames) && is_array($clInt) && is_array($clNames) && 
 		    is_array($clQdisc) && is_array($clRate) && is_array($clCeil))
 		foreach ($clIndex as $pos=>$index) { 
