@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //Aggregated Used Storage Graph
 
 function graph_storage_aggregation ($data) { 
@@ -20,7 +24,7 @@ function graph_storage_aggregation ($data) {
 				    "storage_block_size_b$id"=>"storage_block_size",	
 				    "storage_used_blocks_b$id"=>"storage_used_blocks"));
 
-	$aux = array_merge ($defs,array (
+	$aux = @array_merge ($defs,array (
     	    "CDEF:storage_block_count$id=storage_block_count_b$id", 
     	    "CDEF:storage_used_blocks$id=storage_used_blocks_b$id", 
     	    "CDEF:storage_block_size$id=storage_block_size_b$id", 
@@ -35,13 +39,13 @@ function graph_storage_aggregation ($data) {
 	    "CDEF:storage_used_p$id=storage_used$id,100,*,storage_total$id,/"
 	));
 
-	$opts_DEF = array_merge ($opts_DEF, $aux);
+	$opts_DEF = @array_merge ($opts_DEF, $aux);
 
 	$description = substr(str_pad($interface["host_name"]." ".$interface["interface"],60," ",STR_PAD_RIGHT),0,25);
 	$description = str_replace (":","\:",$description); //escape : for Windows Disks
 	$used_color = $colors[++$i*2];
 	
-	$opts_GRAPH = array_merge ($opts_GRAPH,array(
+	$opts_GRAPH = @array_merge ($opts_GRAPH,array(
     	    "LINE2:storage_used$id#$used_color:'$description'", 
 	    
 	    "GPRINT:storage_total$id:MAX:'%6.0lf %sB'",
