@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 function poller_cisco_saagent_rtl($options) {
         
     if ( !is_array($GLOBALS["cisco_saagent_rtl"][$options["host_id"]]) ) {
@@ -12,8 +16,6 @@ function poller_cisco_saagent_rtl($options) {
 	foreach ( $rtlsum as $key=>$entry ) {
     	    $key=explode(".",$key);
             $key=$key[count($key)-1];
-	    $entry=explode(":",$entry);
-            $entry=trim($entry[1]);
 
             $rtlsum[$key]=$entry;
         }
@@ -22,8 +24,7 @@ function poller_cisco_saagent_rtl($options) {
 	foreach ( $rtlnum as $key=>$entry ) { 
     	    $key=explode(".",$key);
             $key=$key[count($key)-1];
-	    $entry=explode(":",$entry);
-	    $entry=trim($entry[1]);
+
             $rtlnum[$key]=$entry;
         }
 
