@@ -64,7 +64,7 @@ function poller_tcp_port_content ($options) {
 		echo "REGEXP: $regexp\nDATA: $data\n"; //DEBUG
 		
 		if (preg_match($regexp,$data,$parts)==true) {
-		    var_dump($parts); //DEBUG
+		    //var_dump($parts); //DEBUG
 		
 		    $valid = true;
 		
