@@ -7,10 +7,16 @@
     
     if (!profile("ADMIN_HOSTS")) die ("<H1> You dont have Permission to access this page.</H1></HTML>");
 
+    $action = $Sanitizer->get_string('action');
+    $actionid = $Sanitizer->get_int('actionid');
+    $alarm_filters = $Sanitizer->get_string('alarm_filters',FALSE,TRUE);
+    $init = $Sanitizer->get_int('init', 0);
+    $span = $Sanitizer->get_int('span',20);
+    
     adm_header("Alarm Editor");
 
-    $interfaces = $jffnms->get("interfaces");
-    $alarms = $jffnms->get("alarms");
+    $Interfaces = new JffnmsInterfaces();
+    $Alarms = new JffnmsAlarms();
     
     $id = $actionid;
     if (!is_array($actionid)) $actionid=array($actionid);
@@ -19,7 +25,7 @@
 	if (empty($triggered)) $triggered = 0;
 	
 	$data = compact("date_start","date_stop","interface","active","referer_start","referer_stop","triggered","type");
-	$alarms->update($id,$data);
+	$Alarms->update($id,$data);
 	$action="list";
     }
 
@@ -27,7 +33,7 @@
         
 	foreach ($actionid as $id) 
 	    if (is_numeric($id)) 
-	        $alarms->delete($id);
+	        $Alarms->delete($id);
 
 	$action="list";
     }
@@ -36,7 +42,7 @@
 
     $interface_filters = reports_make_interface_filter();
 
-    $interfaces_list = $interfaces->get_all($use_interfaces, $interface_filters);
+    $interfaces_list = $Interfaces->get_all($use_interfaces, $interface_filters);
     
     $interfaces_ids_list = array_keys($interfaces_list);
 
@@ -44,7 +50,7 @@
 	foreach ($alarm_filters as $key=>$value)
 	    if (empty($value) || !is_string($key)) unset($alarm_filters[$key]);
 
-    $alarms_list_cant = $alarms->get($interfaces_ids_list,$alarm_filters);
+    $alarms_list_cant = $Alarms->get($interfaces_ids_list,$alarm_filters);
 
     echo
 	adm_table_header("Alarm Editor", $init, &$span, $fields, $alarms_list_cant, "admin_alarms", false).
@@ -65,11 +71,11 @@
     adm_form("update");
     echo reports_pass_options();
 
-    $alarms->slice($init,$span);
+    $Alarms->slice($init,$span);
 
     if ($alarms_list_cant > 0) {
 
-	while ($r = $alarms->fetch()) {
+	while ($r = $Alarms->fetch()) {
 
 	    echo tr_open("row_".$rec["id"],
 		((in_array($r["id"],$actionid) && ($action=="edit"))
@@ -90,7 +96,7 @@
 		    td(textbox("referer_start",$r["referer_start"],5)." / ".textbox("referer_stop",$r["referer_stop"],5), "field");
 	    else
 		echo 
-		    adm_standard_edit_delete($r["id"],false).
+		    adm_standard_edit_delete($r["id"],'', FALSE).
 		    td($r["id"],"field","field_id").
 	    	    td($r["date_start"],"field").
 	    	    td($r["date_stop"],"field").
