@@ -5,7 +5,7 @@
  */
     class jffnms_satellites	extends internal_base_standard 	{ 
 	var $jffnms_class = "satellites"; 
-	var $jffnms_insert = array(description=>"New Satellite"); 
+	var $jffnms_insert = array('description'=>"New Satellite"); 
 	
 	//get data about satellites
         function get_all()		{ $params = func_get_args(); return call_user_func_array("satellites_list",$params); }
@@ -284,7 +284,7 @@
 	
 	    $jffnms = new jffnms(0); //new jffnms object broker
 
-	    $time_dist_total = time_usec();
+	    $time_dist_total = time_msec();
     
 	    //general data
 	    $distribution_plan = Array (
@@ -318,7 +318,7 @@
 		if ($data_type_orig) {
 		    list ($data_type,) = explode (":",$data_type_orig);
 		    
-		    $time_dist_export = time_usec();
+		    $time_dist_export = time_msec();
 		
 		    $obj = $jffnms->get($data_type);
 		    $data = $obj->export($filter);
@@ -334,7 +334,7 @@
 			    filter=>$filter
 			))
 		    );
-		    $time_dist_send = time_usec();
+		    $time_dist_send = time_msec();
 		    //$debug = true;
     
     		    if (!$debug) {
@@ -350,7 +350,7 @@
 		    //debug ($result);
 		    //die();
 
-		    $time_dist_send = time_usec_diff($time_dist_send);
+		    $time_dist_send = time_msec_diff($time_dist_send);
 		    
 		    //counters
 		    $info[data][$data_type_orig][time_send]=$time_dist_send;
@@ -381,7 +381,7 @@
 		    //break;
 		}
 	
-    	    $info[total_time]= time_usec_diff($time_dist_total);
+    	    $info[total_time]= time_msec_diff($time_dist_total);
 
 	    $info[traceroute]=$result[traceroute];
 	    $info[items]=count($info[data]);
